@@ -129,7 +129,7 @@
   
   DESCRIPTION:
   
-  $Id: icalssyacc.c,v 1.11 2008-01-14 00:35:26 dothebart Exp $
+  $Id: icalssyacc.y,v 1.10 2008-01-14 00:35:26 dothebart Exp $
   $Locker:  $
 
 (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -164,14 +164,23 @@ extern struct icalgauge_impl *icalss_yy_gauge;
 #define YY_EXTRA_TYPE  icalgauge_impl*
 
 
+void sserror(char *s); 
+
 static void ssyacc_add_where(struct icalgauge_impl* impl, char* prop, 
 			icalgaugecompare compare , char* value);
 static void ssyacc_add_select(struct icalgauge_impl* impl, char* str1);
 static void ssyacc_add_from(struct icalgauge_impl* impl, char* str1);
 static void set_logic(struct icalgauge_impl* impl,icalgaugelogic l);
-void sserror(char *s); /* Don't know why I need this.... */
-int sslex(void *YYPARSE_PARAM);
 
+/* Don't know why I need this....  */
+ 
+/* TODO: older flex version produce whats here configured as OpenBSD */
+/* autoconf should figure out, and which flex version we should be newer than? */
+#ifndef __OpenBSD__
+int sslex(void *YYPARSE_PARAM);
+#else
+int sslex();
+#endif
 
 
 /* Enabling traces.  */
@@ -194,12 +203,12 @@ int sslex(void *YYPARSE_PARAM);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 54 "icalssyacc.y"
+#line 63 "icalssyacc.y"
 {
 	char* v_string;
 }
 /* Line 187 of yacc.c.  */
-#line 203 "icalssyacc.c"
+#line 212 "y.tab.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -212,7 +221,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 216 "icalssyacc.c"
+#line 225 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -504,9 +513,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    65,    65,    66,    67,    74,    75,    80,    81,    84,
-      86,    87,    88,    89,    90,    91,    92,    93,    97,    98,
-      99
+       0,    74,    74,    75,    76,    83,    84,    89,    90,    93,
+      95,    96,    97,    98,    99,   100,   101,   102,   106,   107,
+     108
 };
 #endif
 
@@ -1427,7 +1436,7 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 67 "icalssyacc.y"
+#line 76 "icalssyacc.y"
     { 
                  yyclearin;
 		 YYABORT;
@@ -1435,83 +1444,83 @@ yyreduce:
     break;
 
   case 5:
-#line 74 "icalssyacc.y"
+#line 83 "icalssyacc.y"
     {ssyacc_add_select(icalss_yy_gauge,(yyvsp[(1) - (1)].v_string));}
     break;
 
   case 6:
-#line 75 "icalssyacc.y"
+#line 84 "icalssyacc.y"
     {ssyacc_add_select(icalss_yy_gauge,(yyvsp[(3) - (3)].v_string));}
     break;
 
   case 7:
-#line 80 "icalssyacc.y"
+#line 89 "icalssyacc.y"
     {ssyacc_add_from(icalss_yy_gauge,(yyvsp[(1) - (1)].v_string));}
     break;
 
   case 8:
-#line 81 "icalssyacc.y"
+#line 90 "icalssyacc.y"
     {ssyacc_add_from(icalss_yy_gauge,(yyvsp[(3) - (3)].v_string));}
     break;
 
   case 10:
-#line 86 "icalssyacc.y"
+#line 95 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_EQUAL,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 11:
-#line 87 "icalssyacc.y"
+#line 96 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_ISNULL,""); }
     break;
 
   case 12:
-#line 88 "icalssyacc.y"
+#line 97 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (4)].v_string),ICALGAUGECOMPARE_ISNOTNULL,""); }
     break;
 
   case 13:
-#line 89 "icalssyacc.y"
+#line 98 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_NOTEQUAL,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 14:
-#line 90 "icalssyacc.y"
+#line 99 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_LESS,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 15:
-#line 91 "icalssyacc.y"
+#line 100 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_GREATER,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 16:
-#line 92 "icalssyacc.y"
+#line 101 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_LESSEQUAL,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 17:
-#line 93 "icalssyacc.y"
+#line 102 "icalssyacc.y"
     {ssyacc_add_where(icalss_yy_gauge,(yyvsp[(1) - (3)].v_string),ICALGAUGECOMPARE_GREATEREQUAL,(yyvsp[(3) - (3)].v_string)); }
     break;
 
   case 18:
-#line 97 "icalssyacc.y"
+#line 106 "icalssyacc.y"
     {set_logic(icalss_yy_gauge,ICALGAUGELOGIC_NONE);}
     break;
 
   case 19:
-#line 98 "icalssyacc.y"
+#line 107 "icalssyacc.y"
     {set_logic(icalss_yy_gauge,ICALGAUGELOGIC_AND);}
     break;
 
   case 20:
-#line 99 "icalssyacc.y"
+#line 108 "icalssyacc.y"
     {set_logic(icalss_yy_gauge,ICALGAUGELOGIC_OR);}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1515 "icalssyacc.c"
+#line 1524 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1725,7 +1734,7 @@ yyreturn:
 }
 
 
-#line 103 "icalssyacc.y"
+#line 112 "icalssyacc.y"
 
 
 static void ssyacc_add_where(struct icalgauge_impl* impl, char* str1, 
